require 'spec_helper'

RSpec.describe GTM::Bootstrap do
  context '::extract_scope' do
    it 'extracts empty scope' do
      args = ['', nil]
      args.each do |arg|
        scope = GTM::Bootstrap.extract_scope arg
        expect(scope).to eql({path: ''})
      end
      args = %w(data data/)
      args.each do |arg|
        scope = GTM::Bootstrap.extract_scope arg
        expect(scope).to eql({
                                 path: 'data/'
                             })
      end
    end

    it 'extracts only account_id' do
      args = %w(data/202287 data/202287/)
      args.each do |arg|
        scope = GTM::Bootstrap.extract_scope arg
        expect(scope).to eql({
                                 path: 'data/',
                                 account_id: '202287'
                             })
      end
    end

    it 'extracts account_id and container' do
      args = %w(202287/de_nec_package/ 202287/de_nec_package)
      args.each do |arg|
        scope = GTM::Bootstrap.extract_scope arg
        expect(scope).to eql({
                                 path: '',
                                 account_id: '202287',
                                 container_name: 'de_nec_package'
                             })
      end
    end

    it 'extracts account_id, container and tag' do
      arg = '202287/de_nec_package/tags/facebook.html'
      scope = GTM::Bootstrap.extract_scope arg
      expect(scope).to eql({
                               path: '',
                               account_id: '202287',
                               container_name: 'de_nec_package',
                               tag_file: 'facebook.html'
                           })
    end

    it 'extracts the correct path' do
      arg = '/usr/an/absolute_path/202287'
      scope = GTM::Bootstrap.extract_scope arg
      expect(scope[:path]).to eql('/usr/an/absolute_path/')
      args = %w(long/path/to/test/here/we/go long/path/to/test/here/we/go/202287 long/path/to/test/here/we/go/202287/de_nec_package/tags/facebook.html long/path/to/test/here/we/go/202287/de_nec_package)
      args.each do |arg|
        scope = GTM::Bootstrap.extract_scope arg
        expect(scope[:path]).to eql('long/path/to/test/here/we/go/')
      end
    end
  end
end